pywurfl.exceptions.DeviceNotFound

Package pywurfl :: Module exceptions :: Class DeviceNotFound |
[hide private]
[frames] | no frames]

# Class DeviceNotFound

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                      WURFLException --+
                                       |
                                      DeviceNotFound

Device Not Found exception class

Raised when pywurfl cannot find a device by using either select_* API functions.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`